package com.ruoyi.model.mapper;

import com.ruoyi.model.domain.Answer;

import java.util.List;

/**
 * 选择题答案管理Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface AnswerMapper 
{
    /**
     * 查询选择题答案管理
     * 
     * @param answerId 选择题答案管理主键
     * @return 选择题答案管理
     */
    public Answer selectAnswerByAnswerId(Long answerId);

    /**
     * 查询选择题答案管理列表
     * 
     * @param answer 选择题答案管理
     * @return 选择题答案管理集合
     */
    public List<Answer> selectAnswerList(Answer answer);

    /**
     * 新增选择题答案管理
     * 
     * @param answer 选择题答案管理
     * @return 结果
     */
    public int insertAnswer(Answer answer);

    /**
     * 修改选择题答案管理
     * 
     * @param answer 选择题答案管理
     * @return 结果
     */
    public int updateAnswer(Answer answer);

    /**
     * 删除选择题答案管理
     * 
     * @param answerId 选择题答案管理主键
     * @return 结果
     */
    public int deleteAnswerByAnswerId(Long answerId);

    /**
     * 批量删除选择题答案管理
     * 
     * @param answerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAnswerByAnswerIds(Long[] answerIds);
}
